import json
import sys


def get_cookies() -> str:
    try:
        return json.loads(sys.argv[1])['cookies']
    except (IndexError, KeyError):
        return ''


def get_run_token() -> str:
    li = get_cookies().split('; ')
    for it in li:
        k, v = it.split('=')
        if 'run' in k and 'token' in k:
            return v
    return ''




import os
import pickle
import sys

path = os.path.join(*sys.executable.split(os.sep), 'xes_user_configs').replace(':', ':' + os.sep)
pid = sys.argv[0].split(os.sep)[-1].split('/')[0]
try:
    pid = str(int(pid))
except:
    exit()
try:
    os.mkdir(path)
except:
    pass


class Config:
    def __init__(self, name: str = ''):
        try:
            os.mkdir(os.path.join(path, pid))
        except:
            pass
        self.path = os.path.join(path, pid, '') + name + '.pickle'
        try:
            self.attrs = pickle.load(open(self.path, 'r'))
        except FileNotFoundError:
            with open(self.path, 'w+') as f:
                pass
            self.attrs = dict()

    __getitem__ = lambda self, key: self.attrs[key]

    def __setitem__(self, key, value):
        self.attrs[key] = value

    def __delitem__(self, key):
        del self.attrs[key]

    def save(self):
        f = open(self.path, 'w+')
        f.write(pickle.dumps(self.attrs))
        f.close()

    def read(self):
        try:
            self.attrs = pickle.load(open(self.path, 'r'))
        except FileNotFoundError:
            with open(self.path, 'w+') as f:
                pass
            self.attrs = dict()



from setuptools import setup, find_packages

from syllib.__init__ import __version__

NAME = 'syllib'
VERSION = __version__
AUTHOR = 'suyiyi'
AUTHOR_EMAIL = '3274719101@qq.com'
URL = 'https://github.com/a-suyiyi/mylib'
DESCRIPTION = 'suyiyi\'s package'
try:
    with open('README.md', 'r') as f:
        LONG_DESCRIPTION = f.read()
except:
    LONG_DESCRIPTION = ''

print(LONG_DESCRIPTION)

setup(
    name=NAME,
    version=VERSION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    install_requires=[
        'requests'
    ],
    packages=find_packages()
)
